<?php

namespace Drupal\graphql_address\Plugin\GraphQL\Fields\Address;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * The list of administrative areas for a country.
 *
 * @GraphQLField(
 *   secure = true,
 *   id = "prosple_address_admin_areas",
 *   name = "administrativeAreas",
 *   parents = {"AddressCountry"},
 *   type = "[AddressAdministrativeArea]",
 * )
 */
class AddressAdministrativeAreas extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {

    $administrative_areas = \Drupal::service('address.subdivision_repository')->getList([$value['country']]);

    /**
     * @var $administrative_area \CommerceGuys\Addressing\Subdivision\Subdivision
     */
    foreach ($administrative_areas as $admin_area_code => $administrative_area){
      yield [
        'result_type' => 'AddressAdministrativeArea',
        'name' => $administrative_area,
        'parents' => [
          $value['country'],
          $admin_area_code
        ],
      ];
    }
  }

}
